@@ -9,14 +9,17 @@
     :license: MIT, see LICENSE for more details.
 """
 
-import time
 import threading
+from typing import Any, Optional
 
-from .ICache import ICache
-from .CacheEntry import CacheEntry
+from pip_services3_commons.config import ConfigParams
 from pip_services3_commons.config.IReconfigurable import IReconfigurable
 from pip_services3_commons.run.ICleanable import ICleanable
 
+from .CacheEntry import CacheEntry
+from .ICache import ICache
+
+
 class MemoryCache(ICache, IReconfigurable, ICleanable):
     """
     Cache that stores values in the process memory.
@@ -36,55 +39,49 @@ class MemoryCache(ICache, IReconfigurable, ICleanable):
         cache.store("123", "key1", "ABC", 0)
     """
 
-    _default_timeout = 60000
-    _default_max_size = 1000
-
-    _cache = None
-    _count = None
-    _timeout = None
-    _max_size = None
-    _lock = None
+    __default_timeout: int = 60000
+    __default_max_size: int = 1000
 
     def __init__(self):
         """
         Creates a new instance of the cache.
         """
-        self._cache = {}
-        self._count = 0
-        self._max_size = self._default_max_size
-        self._timeout = self._default_timeout
-        self._lock = threading.Lock()
+        self.__cache: dict = {}
+        self.__count: int = 0
+        self.__max_size: int = self.__default_max_size
+        self.__timeout: int = self.__default_timeout
+        self.__lock: threading.Lock = threading.Lock()
 
-    def configure(self, config):
+    def configure(self, config: ConfigParams):
         """
         Configures component by passing configuration parameters.
 
         :param config: configuration parameters to be set.
         """
-        self._timeout = config.get_as_long_with_default("options.timeout", self._default_timeout)
-        self._max_size = config.get_as_long_with_default("options.max_size", self._default_max_size)
+        self.__timeout = config.get_as_long_with_default("options.timeout", self.__default_timeout)
+        self.__max_size = config.get_as_long_with_default("options.max_size", self.__default_max_size)
 
-    def _cleanup(self):
+    def __cleanup(self):
         oldest = None
-        self._count = 0
-        
+        self.__count = 0
+
         # Cleanup obsolete entries and find the oldest
-        for (key, entry) in self._cache.items():
+        for (key, entry) in self.__cache.items():
             # Remove obsolete entry
             if entry.is_expired():
-                self._cache.pop(key, None)
+                self.__cache.pop(key, None)
             # Count the remaining entry 
             else:
-                self._count += 1
+                self.__count += 1
                 if oldest is None or oldest.expiration > entry.expiration:
                     oldest = entry
-        
-        # Remove the oldest if cache size exceeded maximum
-        if self._count > self._max_size and not (oldest is None):
-            self._cache.pop(oldest.key, None)
-            self._count -= 1
 
-    def retrieve(self, correlation_id, key):
+        # Remove the oldest if cache size exceeded maximum
+        if self.__count > self.__max_size and not (oldest is None):
+            self.__cache.pop(oldest.key, None)
+            self.__count -= 1
+
+    def retrieve(self, correlation_id: Optional[str], key: str) -> Any:
         """
         Retrieves cached value from the cache using its key.
         If value is missing in the cache or expired it returns None.
@@ -95,27 +92,27 @@ class MemoryCache(ICache, IReconfigurable, ICleanable):
 
         :return: a cached value or None if value wasn't found or timeout expired.
         """
-        self._lock.acquire()
+        self.__lock.acquire()
         try:
             # Cache has nothing
-            if key not in self._cache:
+            if key not in self.__cache:
                 return None
-                
+
             # Get entry from the cache
-            entry = self._cache[key]
-                    
+            entry = self.__cache[key]
+
             # Remove entry if expiration set and entry is expired
             if entry.is_expired():
-                self._cache.pop(key, None)
-                self._count -= 1
+                self.__cache.pop(key, None)
+                self.__count -= 1
                 return None
-            
-            # Update access timeout
-            return entry.value
-        finally:
-            self._lock.release()
 
-    def store(self, correlation_id, key, value, timeout):
+            # Update access timeout
+            return entry.get_value()
+        finally:
+            self.__lock.release()
+
+    def store(self, correlation_id: Optional[str], key: str, value: Any, timeout: int) -> Any:
         """
         Stores value in the cache with expiration time.
 
@@ -129,39 +126,39 @@ class MemoryCache(ICache, IReconfigurable, ICleanable):
 
         :return: a cached value stored in the cache.
         """
-        timeout = timeout if timeout > 0 else self._default_timeout
+        timeout = timeout if timeout > 0 else self.__default_timeout
 
-        self._lock.acquire()
+        self.__lock.acquire()
         try:
             entry = None
-            if key in self._cache:
-                entry = self._cache[key]
+            if key in self.__cache:
+                entry = self.__cache[key]
 
             # Shortcut to remove entry from the cache
             if value is None:
                 if not (entry is None):
-                    self._cache.pop(key, None)
-                    self._count -= 1
+                    self.__cache.pop(key, None)
+                    self.__count -= 1
                 return None
-            
+
             # Update the entry
             if not (entry is None):
                 entry.set_value(value, timeout)
             # Or create a new entry 
             else:
                 entry = CacheEntry(key, value, timeout)
-                self._cache[key] = entry
-                self._count += 1
+                self.__cache[key] = entry
+                self.__count += 1
 
             # Clean up the cache
-            if self._max_size > 0 and self._count > self._max_size:
-                self._cleanup()
-            
+            if self.__max_size > 0 and self.__count > self.__max_size:
+                self.__cleanup()
+
             return value
         finally:
-            self._lock.release()
-    
-    def remove(self, correlation_id, key):
+            self.__lock.release()
+
+    def remove(self, correlation_id: Optional[str], key: str):
         """
         Removes a value from the cache by its key.
 
@@ -169,26 +166,25 @@ class MemoryCache(ICache, IReconfigurable, ICleanable):
 
         :param key: a unique value key.
         """
-        self._lock.acquire()
+        self.__lock.acquire()
         try:
             # Get the entry
-            entry = self._cache.pop(key, None)
+            entry = self.__cache.pop(key, None)
 
             # Remove entry from the cache
             if not (entry is None):
-                self._count -= 1
+                self.__count -= 1
         finally:
-            self._lock.release()
-    
-    def clear(self, correlation_id):
+            self.__lock.release()
+
+    def clear(self, correlation_id: Optional[str]):
         """
         Clears component state.
 
         :param correlation_id: (optional) transaction id to trace execution through call chain.
         """
-        self._lock.acquire()
+        self.__lock.acquire()
         try:
-            self._cache = {}
+            self.__cache = {}
         finally:
-            self._lock.release()
-    
\ No newline at end of file
+            self.__lock.release()
